#[non_exhaustive]pub enum AuthoringError {
Show 15 variants
TempDir(Error),
FileOpen {
path: PathBuf,
error: Error,
},
FileRead {
path: PathBuf,
error: Error,
},
IoError(Error),
MalformedPath(PathBuf),
Tarball(Error),
TomlDeserialize {
path: PathBuf,
error: Error,
},
JsonDeserialize {
path: PathBuf,
error: Error,
},
MissingManifest,
Canonicalize {
path: PathBuf,
error: Error,
},
Manifest(ManifestError),
Validation(ValidationError),
PathNotExists {
path: PathBuf,
},
VolumeCreation(Error),
SerdeError(Error),
}Expand description
Errors that may occur while building a package from a directory, a
wasmer.toml manifest, or a tarball.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TempDir(Error)
Unable to create a temporary directory.
FileOpen
Unable to open a file.
FileRead
Unable to read a file.
IoError(Error)
Generic IO error.
MalformedPath(PathBuf)
Unexpected path format
Tarball(Error)
Unable to extract the tarball.
TomlDeserialize
Unable to deserialize the wasmer.toml file.
JsonDeserialize
Unable to deserialize a json file.
MissingManifest
Unable to find the wasmer.toml file.
Canonicalize
Unable to canonicalize a path.
Manifest(ManifestError)
Unable to load the wasmer.toml manifest.
Validation(ValidationError)
A manifest validation error.
PathNotExists
A path in the fs mapping does not exist
VolumeCreation(Error)
Any error happening when populating the volumes tree map of a package
SerdeError(Error)
Error when serializing or deserializing