#[non_exhaustive]pub enum WasmerPackageError {
Authoring(AuthoringError),
ContainerError(ContainerError),
DetectError(DetectError),
}Expand description
Errors that may occur while loading a Wasmer package.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Authoring(AuthoringError)
An error from building or unpacking a package from its sources.
ContainerError(ContainerError)
Container Error
DetectError(DetectError)
Detect Error