#[non_exhaustive]pub enum ManifestError {
Show 14 variants
InvalidDependency(String),
SerializeCborAnnotation {
key: String,
error: Error,
},
UnknownAtomKind(String),
DuplicateModule(String),
ReadAtomFile {
module: String,
path: PathBuf,
error: Error,
},
DuplicateCommand(String),
UnknownRunnerKind(String),
#[non_exhaustive] MergeAnnotations {
command: String,
key: String,
},
InvalidModuleReference {
command: String,
module: String,
},
UndeclaredCommandDependency {
command: String,
dependency: String,
},
WasmerTomlAnnotations {
error: Box<dyn Error + Send + Sync>,
},
OutsideBaseDirectory {
path: PathBuf,
base_dir: PathBuf,
},
MissingFile {
path: PathBuf,
base_dir: PathBuf,
},
FileNotSupported,
}Expand description
Errors that may occur when converting from a wasmer_config::package::Manifest
into a WebC manifest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidDependency(String)
A dependency specification had a syntax error.
SerializeCborAnnotation
Unable to serialize an annotation.
UnknownAtomKind(String)
Specified an unknown atom kind.
DuplicateModule(String)
A module was specified more than once.
ReadAtomFile
Unable to read a module’s source.
Fields
DuplicateCommand(String)
A command was specified more than once.
UnknownRunnerKind(String)
An unknown runner kind was specified.
#[non_exhaustive]MergeAnnotations
An error occurred while merging user-defined annotations in with automatically generated ones.
Fields
This variant is marked as non-exhaustive
InvalidModuleReference
A command uses a non-existent module.
UndeclaredCommandDependency
A command references a module from an undeclared dependency.
WasmerTomlAnnotations
Unable to deserialize custom annotations from the wasmer.toml
manifest.
OutsideBaseDirectory
The wasmer.toml file references a file outside of its base directory.
MissingFile
The manifest references a file that doesn’t exist.
FileNotSupported
File based commands are not supported for in-memory package creation